<?php
/*
Plugin Name: FullCall
Description: FullCall Widget
Version: 2.0.2
*/

if ( ! defined( 'WPINC' ) ) {
	die;
}

define( 'FULLCALL_URL', wp_normalize_path(plugin_dir_url( __FILE__ )));

class FullCall {
    private $hashName;
    private $webHash;

    public function __construct() 
    {
        $this->hashName = "FullCallHash";
        $this->webHash = get_option($this->hashName, false);
        register_activation_hook( __FILE__, array($this,'install'));
        register_deactivation_hook(__FILE__, array($this, 'deactivation'));
        register_uninstall_hook(__FILE__, array($this, 'uninstall'));
        if($this->webHash != false)
        {
            add_action('wp_enqueue_scripts', array($this,'scripts_styles'));
        }
    }

    private function get_website_url()
    {
        $url = get_site_url();
        $find = array( 'http://www.', 'https://www.', 'https://', 'http://');
        $replace = '';
        $output = str_replace($find, $replace, $url);
        return $output;
    }
    
    public function install()
    {
        if($this->webHash === false)
        {
            $url = $this->get_website_url();
            $response = wp_remote_get("https://app.fullcall.com/api/site/search/{$url}/hash");
            $responseMessage =  $response["response"]["message"];

            if($responseMessage == "OK"){
            $responseBody = wp_remote_retrieve_body($response);
            $this->webHash = $this->getWebHashFromResponseBody($responseBody);
            add_option($this->hashName, $this->webHash);
            }
            else
            {
                $this->webHash = false;
                $this->removeHashFromDB();
                die("Strona: <strong>{$url}</strong> nie została zarejestrowana lub aktywowana na <strong>fullcall.com</strong>.");
            }
        }
    }

    private function getWebHashFromResponseBody($responseBody){
        $webHash = utf8_encode($responseBody);
        $webHash = json_decode($webHash);
        $webHash = $webHash->hash;
        return $webHash;
    }

    public function unsintall(){
        $this->removeHashFromDB();
    }

    public function deactivation(){
        $this->removeHashFromDB();
    }

    private function removeHashFromDB(){
        if(($this->webHash != false) || ($this->webHash == "")){
            delete_option('FullCallHash');
        }
    }

    //scripts to suck in plugin on website
    public function scripts_styles()
    {
        wp_register_script('fc_loader', FULLCALL_URL . 'fc_loader.js');

        if($this->webHash != false)
        {
            wp_localize_script('fc_loader', 'fc_web_hash', $this->webHash);
        }

        wp_enqueue_script('fc_loader');
    }
}

$FullCall = new FullCall();
